@@ -36,6 +36,7 @@ pub struct Beam {
 pub enum Command {
     Connect(command::connect::Connect),
     Profile(command::profile::Profile),
+    #[structopt(alias = "ls")]
     List(command::list::List),
     Completions(command::completions::Completions),
     Configure(command::configure::Configure),
@@ -50,7 +51,7 @@ impl Beam {
         self.execute_command()?;
 
         // Printing notification if the latest version is newer than the current version
-        Beam::check_for_update(latest_version.await??)?;
+        Beam::check_for_update(latest_version.await?)?;
         Ok(())
     }
 
@@ -65,15 +66,17 @@ impl Beam {
         }
     }
 
-    pub fn check_for_update(latest_version: Version) -> Result<()> {
+    pub fn check_for_update(latest_version: Result<Version>) -> Result<()> {
         let current_version = version::get_current_version();
-        if latest_version > current_version {
-            println!(
-                "A new version of beam is available {} -> {}\nTo update run {}",
-                current_version.to_string().red(),
-                latest_version.to_string().green(),
-                "cargo install beamcli".green()
-            );
+        if let Ok(latest_version) = latest_version {
+            if latest_version > current_version {
+                println!(
+                    "A new version of beam is available {} -> {}\nTo update run {}",
+                    current_version.to_string().red(),
+                    latest_version.to_string().green(),
+                    "cargo install beamcli".green()
+                );
+            }
         }
         Ok(())
     }
